@@ -257,6 +257,16 @@ TestDraft6 = DRAFT6.to_unittest_testcase(
         or leap_second(test)
         or missing_format(draft6_format_checker)(test)
         or complex_email_validation(test)
+        or skip(
+            message="id is incorrectly finding non-ids",
+            subject="id",
+            description="const at const_not_anchor does not match",
+        )(test)
+        or skip(
+            message="id is incorrectly finding non-ids",
+            subject="id",
+            description="const at const_not_id does not match",
+        )(test)
         or skip(
             message=bug(),
             subject="refRemote",
@@ -350,6 +360,18 @@ TestDraft201909 = DRAFT201909.to_unittest_testcase(
             message="dynamicRef support isn't working yet.",
             subject="recursiveRef",
         )(test)
+        or skip(
+            message="These tests depends on dynamicRef working.",
+            subject="id",
+            case_description=(
+                "Invalid use of fragments in location-independent $id"
+            ),
+        )(test)
+        or skip(
+            message="These tests depends on dynamicRef working.",
+            subject="defs",
+            description="invalid definition schema",
+        )(test)
         or skip(
             message="These tests depends on dynamicRef working.",
             subject="anchor",
@@ -395,7 +417,15 @@ TestDraft202012 = DRAFT202012.to_unittest_testcase(
     skip=lambda test: (
         narrow_unicode_build(test)
         or skip(
-            message="These tests require an extension or the url resolver.",
+            message="dynamicRef support isn't working yet.",
+            subject="dynamicRef",
+        )(test)
+        or skip(
+            message="These tests depends on dynamicRef working.",
+            subject="defs",
+        )(test)
+        or skip(
+            message="These tests depends on dynamicRef working.",
             subject="anchor",
             case_description="same $anchor with different base uri",
         )(test)
